``ulif.openoffice.oooctl`` -- A Daemon Controlling an OO.o-Server
*****************************************************************

.. automodule:: ulif.openoffice.oooctl
   :members:
   :exclude-members: main

   .. autofunction:: main(argv=sys.argv)
